==> lowcode-editor-core-2.0.5.tgz: package/es/di/datasource.js <==
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
export var DataSourceServiceManager = /*#__PURE__*/function () {
  function DataSourceServiceManager() {
    this.services = new Map();
    this.cache = new Map();
  }
  var _proto = DataSourceServiceManager.prototype;
  _proto.register = function register(key, service) {
    this.services.set(key, service);
  };
  _proto.resolve = /*#__PURE__*/function () {
    var _resolve = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee(key, field, options) {
      var _options$paramsBuilde, _options;
      var cacheKey, service, params, data;
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) switch (_context.prev = _context.next) {
          case 0:
            if (options === void 0) {
              options = {};
            }
            cacheKey = options.cacheable ? key : key + "_" + Date.now();
            if (!(options.cacheable && this.cache.has(cacheKey))) {
              _context.next = 4;
              break;
            }
            return _context.abrupt("return", this.cache.get(cacheKey));
          case 4:
            service = this.services.get(key);
            if (service) {
              _context.next = 7;
              break;
            }
            throw new Error("Data source " + key + " not registered");
          case 7:
            params = ((_options$paramsBuilde = (_options = options).paramsBuilder) === null || _options$paramsBuilde === void 0 ? void 0 : _options$paramsBuilde.call(_options, field)) || {};
            _context.next = 10;
            return service(field, params);
          case 10:
            data = _context.sent;
            if (options.cacheable) {
              this.cache.set(cacheKey, data);
            }
            return _context.abrupt("return", data);
          case 13:
          case "end":
            return _context.stop();
        }
      }, _callee, this);
    }));
    function resolve(_x, _x2, _x3) {
      return _resolve.apply(this, arguments);
    }
    return resolve;
  }();
  return DataSourceServiceManager;
}();

==> lowcode-editor-core-2.0.7.tgz: package/es/di/datasource.js <==
import _extends from "@babel/runtime/helpers/extends";
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import { omit } from 'lodash';
export var DataSourceServiceManager = /*#__PURE__*/function () {
  function DataSourceServiceManager() {
    this.services = new Map();
    this.cache = new Map();
  }
  var _proto = DataSourceServiceManager.prototype;
  _proto.register = function register(key, service) {
    this.services.set(key, service);
  };
  _proto.resolve = /*#__PURE__*/function () {
    var _resolve = _asyncToGenerator(/*#__PURE__*/_regeneratorRuntime.mark(function _callee(key, field, options) {
      var _options$paramsBuilde, _options;
      var cacheKey, service, params, data;
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) switch (_context.prev = _context.next) {
          case 0:
            if (options === void 0) {
              options = {};
            }
            cacheKey = options.cacheable ? key : key + "_" + Date.now();
            if (!(options.cacheable && this.cache.has(cacheKey))) {
              _context.next = 4;
              break;
            }
            return _context.abrupt("return", this.cache.get(cacheKey));
          case 4:
            service = this.services.get(key);
            if (service) {
              _context.next = 7;
              break;
            }
            throw new Error("Data source " + key + " not registered");
          case 7:
            params = ((_options$paramsBuilde = (_options = options).paramsBuilder) === null || _options$paramsBuilde === void 0 ? void 0 : _options$paramsBuilde.call(_options, field)) || _extends({}, omit(options, ['cacheable', 'paramsBuilder']));
            _context.next = 10;
            return service(field, params);
          case 10:
            data = _context.sent;
            if (options.cacheable) {
              this.cache.set(cacheKey, data);
            }
            return _context.abrupt("return", data);
          case 13:
          case "end":
            return _context.stop();
        }
      }, _callee, this);
    }));
    function resolve(_x, _x2, _x3) {
      return _resolve.apply(this, arguments);
    }
    return resolve;
  }();
  return DataSourceServiceManager;
}();
export var SettingScope = /*#__PURE__*/function () {
  function SettingScope() {
    this.scopes = new Map();
  }
  var _proto2 = SettingScope.prototype;
  _proto2.register = function register(key, scope) {
    this.scopes.set(key, scope);
  };
  _proto2.getScopes = function getScopes() {
    return this.scopes.entries().reduce(function (pre, _ref) {
      var key = _ref[0],
        value = _ref[1];
      pre[key] = value;
      return pre;
    }, {});
  };
  return SettingScope;
}();
